
Available log analysis tools
-------

**Description:**

With a log analysis tool in place you can easily and quickly do forensics as soon as you 
notice your application is under attack by attackers and block them out.


**Solution:**

A list of recommended tools by OWASP you can find at 
https://www.owasp.org/index.php/Log_review_and_management#Logging_Tools

	
